cmd.adduser

# cmd.adduser Add a new user to the database

Create a new user in the database.

A user may login to your site with a given username and password.

    $ moya myapp#cmd.adduser EMAIL USERNAME

replace myapp with the name of the installed application

### Positional Arguments

Argument | Description
--- | ---
`EMAIL` | user's email address
`USERNAME` | user's unique username

### Optional Arguments

Argument | Description | Default
--- | --- | ---
`--firstname` | user's forename |
`--group GROUP` | add user to group |
`--lastname` | user's surname |
`--password PASSWORD` | user's password |